pub fn vanilla_template_pools() -> Vec<TemplatePoolData>Expand description
Returns all vanilla template pools parsed from the datapack.
pub fn vanilla_template_pools() -> Vec<TemplatePoolData>Returns all vanilla template pools parsed from the datapack.