pub fn vanilla_templates() -> Vec<(Identifier, TemplateData)>Expand description
Returns all vanilla structure templates with their jigsaw data.
Each entry is (template_key, template_data).
pub fn vanilla_templates() -> Vec<(Identifier, TemplateData)>Returns all vanilla structure templates with their jigsaw data.
Each entry is (template_key, template_data).